@@ -6,11 +6,12 @@
   # require("numDeriv")
   if(interactive())
   {
+    # pkg <- Package("sn")
     meta <- packageDescription("sn")
     packageStartupMessage(
-         "Package 'sn', ", meta$Version, " (", meta$Date, "). ",
-         "Type 'help(SN)' for summary information.",
-         "\n...especially so if have used version 0.x-y in the past")
+      "Package 'sn', ", meta$Version, " (", meta$Date, "). ",
+      "Type 'help(SN)' for summary information.\n",
+      "The package redefines function 'sd' but its usual working is unchanged.")
   }
   invisible()
 }
